@@ -16,7 +16,11 @@
 ( cd usr/bin ; ln -sf setarch linux64 )
 ( cd usr/bin ; rm -rf i386 )
 ( cd usr/bin ; ln -sf setarch i386 )
+( cd lib ; rm -rf libuuid.so.1 )
+( cd lib ; ln -sf libuuid.so.1.3.0 libuuid.so.1 )
 ( cd lib ; rm -rf libblkid.so.1 )
-( cd lib ; ln -sf libblkid.so.1.0.0 libblkid.so.1 )
-( cd lib ; rm -rf libblkid.so )
-( cd lib ; ln -sf libblkid.so.1.0.0 libblkid.so )
+( cd lib ; ln -sf libblkid.so.1.1.0 libblkid.so.1 )
+( cd usr/lib ; rm -rf libuuid.so )
+( cd usr/lib ; ln -sf ../../lib/libuuid.so.1.3.0 libuuid.so )
+( cd usr/lib ; rm -rf libblkid.so )
+( cd usr/lib ; ln -sf ../../lib/libblkid.so.1.1.0 libblkid.so )
